=============
How-To Guides
=============

.. include:: install_tamarco.rst
.. include:: make_the_docs.rst
.. include:: setup_a_logging_backend.rst
.. include:: setup_a_metrics_backend.rst
.. include:: setup_a_setting_backend.rst
.. include:: setup_settings_for_a_specific_microservice.rst
.. include:: setup_settings_for_a_resource.rst
.. include:: use_logging_resource.rst
.. include:: use_metrics_resource.rst
